@@ -69,7 +69,7 @@ void Graphics::free()
 	while (sprite->next != NULL)
 	{
 		sprite = (Sprite*)sprite->next;
-		debug(("graphics.free: Sprites Sprite::Free - %s\n", sprite->name));
+		//debug(("graphics.free: Sprites Sprite::Free - %s\n", sprite->name));
 		sprite->free();
 	}
 	debug(("graphics.free: Sprites Clear()\n"));
@@ -148,7 +148,7 @@ void Graphics::updateScreen()
 
 	if (takeRandomScreenShots)
 	{
-		if ((rand() % 500) == 0)
+		if ((Math::prand() % 500) == 0)
 		{
 			sprintf(screenshot, "screenshots/screenshot%.3d.bmp", screenShotNumber);
 			SDL_SaveBMP(screen, screenshot);
@@ -299,7 +299,7 @@ void Graphics::HSVtoRGB(float *r, float *g, float *b, float h, float s, float v)
 	}
 }
 
-SDL_Surface *Graphics::loadImage(char *filename)
+SDL_Surface *Graphics::loadImage(const char *filename)
 {
 	SDL_Surface *image, *newImage;
 
@@ -331,7 +331,7 @@ SDL_Surface *Graphics::loadImage(char *filename)
 	return newImage;
 }
 
-SDL_Surface *Graphics::loadImage(char *filename, int hue, int sat, int value)
+SDL_Surface *Graphics::loadImage(const char *filename, int hue, int sat, int value)
 {
 	SDL_Surface *image, *newImage;
 
@@ -401,7 +401,7 @@ SDL_Surface *Graphics::loadImage(char *filename, int hue, int sat, int value)
 	return newImage;
 }
 
-SDL_Surface *Graphics::quickSprite(char *name, SDL_Surface *image)
+SDL_Surface *Graphics::quickSprite(const char *name, SDL_Surface *image)
 {
 	Sprite *sprite = addSprite(name);
 	sprite->setFrame(0, image, 60);
@@ -428,7 +428,7 @@ void Graphics::fadeToBlack()
 	}
 }
 
-void Graphics::loadMapTiles(char *baseDir)
+void Graphics::loadMapTiles(const char *baseDir)
 {
 	bool found, autoAlpha;
 	char filename[255];
@@ -491,7 +491,7 @@ If a user has a resolution other than approximately 72dpi then
 they will get a small or larger font and this won't work. This might look
 weird since we'll load and delete multiple fonts, but it works...
 */
-void Graphics::loadFont(int i, char *filename, int pixelSize)
+void Graphics::loadFont(int i, const char *filename, int pixelSize)
 {
 	int minx, maxx, miny, maxy, advance;
 	
@@ -564,7 +564,7 @@ void Graphics::loadFont(int i, char *filename, int pixelSize)
 	debug(("Got a match for font size %d - Nearest = %d\n", pixelSize, maxx));
 }
 
-Sprite *Graphics::addSprite(char *name)
+Sprite *Graphics::addSprite(const char *name)
 {
 	Sprite *sprite = new Sprite;
 	strcpy(sprite->name, name);
@@ -574,7 +574,7 @@ Sprite *Graphics::addSprite(char *name)
 	return sprite;
 }
 
-Sprite *Graphics::getSprite(char *name, bool required)
+Sprite *Graphics::getSprite(const char *name, bool required)
 {
 	Sprite *sprite = (Sprite*)spriteList.getHead();
 
@@ -636,7 +636,7 @@ int Graphics::getLavaAnim(int current)
 	return current;
 }
 
-void Graphics::loadBackground(char *filename)
+void Graphics::loadBackground(const char *filename)
 {
 	if (background != NULL)
 		SDL_FreeSurface(background);
@@ -824,7 +824,7 @@ void Graphics::setFontSize(int size)
 	Math::limitInt(&fontSize, 0, 4);
 }
 
-SDL_Surface *Graphics::getString(char *in, bool transparent)
+SDL_Surface *Graphics::getString(const char *in, bool transparent)
 {
 	SDL_Surface *text = TTF_RenderUTF8_Shaded(font[fontSize], in, fontForeground, fontBackground);
 
@@ -839,7 +839,7 @@ SDL_Surface *Graphics::getString(char *in, bool transparent)
 	return text;
 }
 
-void Graphics::drawString(char *in, int x, int y, int alignment, SDL_Surface *dest)
+void Graphics::drawString(const char *in, int x, int y, int alignment, SDL_Surface *dest)
 {
 	bool center = false;
 
@@ -863,7 +863,7 @@ void Graphics::clearChatString()
 	strcpy(chatString, "");
 }
 
-void Graphics::createChatString(char *in)
+void Graphics::createChatString(const char *in)
 {
 	sprintf(chatString, "%s %s", chatString, in);
 }
@@ -1047,7 +1047,7 @@ void Graphics::showLicenseErrorAndExit()
 	}
 }
 
-void Graphics::showErrorAndExit(char *error, char *param)
+void Graphics::showErrorAndExit(const char *error, const char *param)
 {
 	SDL_FillRect(screen, NULL, black);
 
