@@ -31,5 +31,5 @@ class HubLevel : public GameObject {
 		Sprite *target;
 
 	HubLevel();
-	void set(char *stageName, char *filename, int x, int y);
+	void set(const char *stageName, const char *filename, int x, int y);
 };
