@@ -25,6 +25,8 @@ class Math {
 		Math(){}
 
 	public:
+	
+		static unsigned int pSeed;
 
 	static void limitChar(signed char *in, int low, int high);
 	static void limitChar(unsigned char *in, int low, int high);
@@ -33,10 +35,11 @@ class Math {
 	static void wrapChar(signed char *in, signed char low, signed char high);
 	static void wrapInt(int *in, int low, int high);
 	static void wrapFloat(float *in, float low, float high);
+	static int prand();
 	static int rrand(int min, int max);
-	static bool boolFromWord(char *word);
+	static bool boolFromWord(const char *word);
 	static void addBit(long *currentBits, long newBits);
 	static void removeBit(long *currentBits, long oldBits);
 	static void calculateSlope(float x, float y, float x2, float y2, float *dx, float *dy);
-
+	static char *formatTime(int seconds);
 };
