@@ -27,6 +27,6 @@ class PersistData : public GameObject {
 	PersistData();
 	~PersistData();
 	
-	bool setData(char *data);
+	bool setData(const char *data);
 
 };
