@@ -62,7 +62,7 @@ void blackDroidDie()
 	
 	if (self->health <= -60)
 	{
-		if ((rand() % 2) == 0)
+		if ((Math::prand() % 2) == 0)
 		{
 			dropItems((int)self->x, (int)self->y);
 			dropItems((int)self->x, (int)self->y);
@@ -115,7 +115,7 @@ void blackDroidAttack()
 	self->setThinkTime(2);
 	self->setActionFinished(2);
 	
-	int r = rand() % 15;
+	int r = Math::prand() % 15;
 	
 	if (r <= 2)
 	{
@@ -370,7 +370,7 @@ void galdovMiniAttack()
 	self->setThinkTime(2);
 	self->setActionFinished(2);
 	
-	int r = rand() % 100;
+	int r = Math::prand() % 100;
 	
 	if (r < 10)
 	{
@@ -396,7 +396,7 @@ void galdovMiniAttack()
 	}
 	else
 	{
-		if ((self->flags & ENT_FLIES) && (rand() % 5) == 0)
+		if ((self->flags & ENT_FLIES) && (Math::prand() % 5) == 0)
 		{
 			Math::removeBit(&self->flags, ENT_FLIES);
 			Math::removeBit(&self->flags, ENT_FIRETRAIL);
@@ -449,7 +449,7 @@ void galdovRejoin()
 		{
 			addTeleportParticles(map.boss[i]->x + 4, map.boss[i]->y + 4, 75, -1);
 			
-			if ((rand() % (2 + (game.skill))) == 0)
+			if ((Math::prand() % (2 + (game.skill))) == 0)
 			{
 				dropItems((int)map.boss[i]->x, (int)map.boss[i]->y);
 			}
@@ -542,7 +542,7 @@ void galdovFinalReact()
 {
 	map.boss[0]->health = 45 * game.skill;
 	
-	if ((rand() % 5) == 0)
+	if ((Math::prand() % 5) == 0)
 	{
 		map.boss[0]->setThinkTime(2);
 		map.boss[0]->setActionFinished(2);
@@ -589,7 +589,7 @@ void galdovFinalReact2()
 	if (self->health < 1)
 		return;
 	
-	if ((rand() % 12) == 0)
+	if ((Math::prand() % 12) == 0)
 	{
 		addTeleportParticles(self->x + (self->width / 2), self->y + (self->height / 2), 50, SND_TELEPORT3);
 		map.boss[0]->setThinkTime(2);
