@@ -173,7 +173,7 @@ void createStatsPanel(int page)
 		graphics.blit(arrows->image[3], 200, 260, image, false);
 }
 
-void loadLevelBrief(char *levelName)
+void loadLevelBrief(const char *levelName)
 {
 	char briefLine[1024];
 
@@ -228,7 +228,7 @@ void loadLevelBrief(char *levelName)
 	graphics.drawChatString(image, 40);
 }
 
-void createObjectivesPanel(char *levelName)
+void createObjectivesPanel(const char *levelName)
 {
 	SDL_Surface *image = graphics.getSprite("infoPanel", true)->image[0];
 
@@ -403,7 +403,7 @@ void createMIAPanel(int start, int max)
 		graphics.blit(arrows->image[3], 200, 260, image, false);
 }
 
-bool requirementMet(char *requiredLevel)
+bool requirementMet(const char *requiredLevel)
 {
 	if (engine.cheatLevels)
 	{
@@ -615,26 +615,24 @@ int doHub()
 		#endif
 
 		engine.getInput();
+		config.populate();
 		
-		mouseXDelta = engine.getJoyX(8);
-		mouseYDelta = engine.getJoyY(8);
-
-		if (engine.isKey(KEY_RIGHT))
+		if (config.isControl(CONTROL::RIGHT))
 		{
 			mouseXDelta = 5;
 		}
 		
-		if (engine.isKey(KEY_LEFT))
+		if (config.isControl(CONTROL::LEFT))
 		{
 			mouseXDelta = -5;
 		}
 		
-		if (engine.keyState[SDLK_DOWN])
+		if (config.isControl(CONTROL::DOWN))
 		{
 			mouseYDelta = 5;
 		}
 		
-		if (engine.keyState[SDLK_UP])
+		if (config.isControl(CONTROL::UP))
 		{
 			mouseYDelta = -5;
 		}
@@ -642,6 +640,8 @@ int doHub()
 		if ((mouseXDelta != 0) || (mouseYDelta != 0))
 		{
 			engine.setMouse(engine.getMouseX() + (int)mouseXDelta, engine.getMouseY() + (int)mouseYDelta);
+			mouseXDelta = 0;
+			mouseYDelta = 0;
 		}
 
 		hubPoint = (HubLevel*)hubList.getHead();
@@ -664,16 +664,16 @@ int doHub()
 
 				graphics.blit(hubPoint->levelNameImage, labelX, labelY, graphics.screen, true);
 
-				if (engine.mouseLeft || engine.isKey(KEY_FIRE))
+				if (engine.mouseLeft || config.isControl(CONTROL::FIRE))
 				{
 					game.setMapName(hubPoint->filename);
 					game.setStageName(hubPoint->stageName);
 					validStage = true;
 					engine.mouseLeft = 0;
-					engine.clearKey(KEY_FIRE);
+					config.resetControl(CONTROL::FIRE);
 				}
 
-				if (engine.mouseRight || engine.isKey(KEY_MAP))
+				if (engine.mouseRight || config.isControl(CONTROL::MAP))
 				{
 					game.setMapName(hubPoint->filename);
 					game.setStageName(hubPoint->stageName);
@@ -681,7 +681,7 @@ int doHub()
 					showData = true;
 					showStats = false;
 					engine.mouseRight = 0;
-					engine.clearKey(KEY_MAP);
+					config.resetControl(CONTROL::MAP);
 				}
 			}
 		}
@@ -692,7 +692,7 @@ int doHub()
 			graphics.blit(hubIcons->image[i], 50 + (i * 100), 440, graphics.screen, false);
 			if (Collision::collision(engine.getMouseX(), engine.getMouseY(), 1, 1, 50 + (i * 100), 440, hubIcons->image[i]->w, hubIcons->image[i]->h))
 			{
-				if (engine.mouseLeft || engine.isKey(KEY_FIRE))
+				if (engine.mouseLeft || config.isControl(CONTROL::FIRE))
 				{
 					switch (i)
 					{
@@ -725,7 +725,7 @@ int doHub()
 					}
 
 					engine.mouseLeft = false;
-					engine.keyState[SDLK_LCTRL] = 0;
+					config.resetControl(CONTROL::FIRE);
 				}
 			}
 		}
@@ -733,8 +733,8 @@ int doHub()
 		// Collisions for Panel Buttons
 		if ((showMIAs) || (showStats))
 		{
-		        // SDLK_LCTRL is the "fire" button.
-			if (engine.mouseLeft || engine.isKey(KEY_FIRE))
+		    // SDLK_LCTRL is the "fire" button.
+			if (engine.mouseLeft || config.isControl(CONTROL::FIRE))
 			{
 				if (Collision::collision(engine.getMouseX(), engine.getMouseY(), 1, 1, 270, 310, 32, 32))
 				{
@@ -754,7 +754,7 @@ int doHub()
 					}
 
 					engine.mouseLeft = 0;
-					engine.clearKey(KEY_FIRE);
+					config.resetControl(CONTROL::FIRE);
 				}
 
 
@@ -776,7 +776,7 @@ int doHub()
 					}
 
 					engine.mouseLeft = 0;
-					engine.clearKey(KEY_FIRE);
+					config.resetControl(CONTROL::FIRE);
 				}
 			}
 		}
@@ -784,7 +784,7 @@ int doHub()
 		if ((showData) || (showStats) || (showMIAs))
 		{
 			graphics.blit(infoPanel, 320, 200, graphics.screen, true);
-			if (engine.mouseLeft || engine.isKey(KEY_FIRE))
+			if (engine.mouseLeft || config.isControl(CONTROL::FIRE))
 			{
 				showData = showStats = showMIAs = false;
 			}
