@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 void checkForLicense()
 {
-	if (!engine.loadData(_("data/LICENSE")))
+	if (!engine.loadData(_("data/license")))
 	{
 		graphics.showLicenseErrorAndExit();
 	}
@@ -79,6 +79,7 @@ void showLicense()
 	{
 		graphics.updateScreen();
 		engine.getInput();
+		config.populate();
 		if (engine.keyState[SDLK_SPACE])
 			break;
 		SDL_Delay(16);
@@ -88,37 +89,17 @@ void showLicense()
 	graphics.delay(1000);
 }
 
-/*
-This bit is just for Linux and Unix users. It attempts to get the user's
-home directory, then creates the .parallelrealities and .parallelrealities/blobwars
-directories so that saves and temporary data files can be written there. Good, eh? :)
-*/
 #if UNIX
 void setupUserHomeDirectory()
 {
-	char *userHome;
-
-	char *name = getlogin();
-
-	passwd *pass;
-
-	if (name != NULL)
+	char *userHome = getenv("HOME");
+	
+	if ((!userHome) || (userHome == NULL))
 	{
-		pass = getpwnam(name);
-	}
-	else
-	{
-		pass = getpwuid(geteuid());
-	}
-
-	if (pass == NULL)
-	{
-		printf("Couldn't determine the user home directory. Exitting.\n");
+		printf("Couldn't determine user home directory! Exitting.\n");
 		exit(1);
 	}
 
-	userHome = pass->pw_dir;
-	
 	debug(("User Home = %s\n", userHome));
 	
 	char dir[PATH_MAX];
@@ -142,7 +123,6 @@ void setupUserHomeDirectory()
 	sprintf(gameSavePath, "%s/.parallelrealities/blobwars/", userHome);
 	engine.setUserHome(gameSavePath);
 }
-
 #endif
 
 bool loadConfig()
@@ -187,8 +167,8 @@ bool loadConfig()
 		engine.useAudio = game.output;
 	}
 		
-	engine.loadKeyConfig();
-	engine.loadJoystickConfig();
+	config.loadKeyConfig();
+	config.loadJoystickConfig();
 
 	return rtn;
 }
@@ -222,7 +202,7 @@ BRRRRRRRRRRRRRRRRRMMMMMMMMMMMMMMMMMMM!! Well, hopefully anyway! ;)
 void initSystem()
 {
 	#if UNIX
-		setupUserHomeDirectory();
+	setupUserHomeDirectory();
 	#endif
 
 	bool displayLicense = loadConfig();
@@ -285,18 +265,9 @@ void initSystem()
 
 	if (SDL_NumJoysticks() > 0)
 	{
+		debug(("Opening Joystick - %s...\n", SDL_JoystickName(0)));
 		SDL_JoystickEventState(SDL_ENABLE);
-
-		for (int i = 0 ; i < SDL_NumJoysticks() ; i++)
-		{
-			debug(("Opening Joystick #%d - %s...\n", i, SDL_JoystickName(i)));
-			engine.joystick[i] = SDL_JoystickOpen(i);
-			
-			if (i == 1)
-			{
-				break;
-			}
-		}
+		config.sdlJoystick = SDL_JoystickOpen(0);
 	}
 
 	SDL_ShowCursor(SDL_DISABLE);
@@ -370,8 +341,6 @@ void initSystem()
 	{
 		checkForLicense();
 	}
-		
-	srand(time(NULL));
 	
 	engine.saveConfig = true;
 
@@ -388,6 +357,9 @@ void cleanup()
 	char tempPath[PATH_MAX];
 	
 	debug(("Cleaning Up...\n"));
+	
+	debug(("Updating Replay Data\n"));
+	replayData.header.score = game.score;
 
 	debug(("Freeing Audio...\n"));
 	audio.destroy();
@@ -424,7 +396,7 @@ void cleanup()
 		for (int i = 0 ; i < SDL_NumJoysticks() ; i++)
 		{
 			debug(("Closing Joystick #%d - %s...\n", i, SDL_JoystickName(i)));
-			SDL_JoystickClose(engine.joystick[i]);
+			SDL_JoystickClose(config.sdlJoystick);
 		}
 	}
 
@@ -441,5 +413,11 @@ void cleanup()
 	SDL_Quit();
 
 	debug(("All Done.\n"));
+	
+	if (replayData.replayMode == REPLAY_MODE::PLAYBACK)
+	{
+		printf("\n==== ACTUAL PLAYBACK DATA ====\n");
+		replayData.printReplayInformation();
+	}
 }
 
