@@ -108,6 +108,7 @@ void showIntroError()
 	{
 		graphics.updateScreen();
 		engine.getInput();
+		config.populate();
 		if (engine.keyState[SDLK_ESCAPE])
 			break;
 		SDL_Delay(16);
@@ -148,7 +149,7 @@ int doIntro()
 
 	for (int i = 0 ; i < 4 ; i++)
 	{
-		addItem(101, "CherryPlant", rand() % 640, 9050, "CherryPlant", 100, 1, 0, false);
+		addItem(101, "CherryPlant", Math::prand() % 640, 9050, "CherryPlant", 100, 1, 0, false);
 	}
 
 	if (!engine.loadData(_("data/introText")))
