@@ -403,13 +403,14 @@ void showMap(int centerX, int centerY)
 	while (true)
 	{
 		engine.getInput();
+		config.populate();
 		graphics.updateScreen();
 		graphics.animateSprites();
 
 		graphics.drawRect(160, 120, 320, 240, graphics.black, graphics.white, graphics.screen);
 		graphics.blit(panel, 160, 120, graphics.screen, false);
 
-		if ((engine.isKey(KEY_MAP)) || (engine.isKey(KEY_PAUSE)) || (engine.keyState[SDLK_ESCAPE]))
+		if ((config.isControl(CONTROL::MAP)) || (config.isControl(CONTROL::PAUSE)) || (engine.keyState[SDLK_ESCAPE]))
 		{
 			break;
 		}
@@ -633,7 +634,7 @@ void doWind()
 	addWindParticles();
 }
 
-void parseMapDataLine(char *line, int y)
+void parseMapDataLine(const char *line, int y)
 {
 	int tileIndex = 0;
 	int x = 0;
@@ -659,7 +660,7 @@ void parseMapDataLine(char *line, int y)
 	}
 }
 
-bool loadMapData(char *filename)
+bool loadMapData(const char *filename)
 {
 	map.clear();
 
